@@ -62,7 +62,8 @@ typedef enum _EcgDataConnectionStatus {
 
 typedef enum _HRMName{
 	FRWD,
-	ZEPHYR
+	ZEPHYR,
+	POLAR
 } HRMName;
 /**
  * @brief Struct to hold data for a callback
@@ -186,6 +187,7 @@ struct _EcgData {
 	
 	gchar *bluetooth_name;
 	HRMName *hrm_name;
+	gint hr1,hr2,hr3,count;
 };
 
 /**
